@@ -4,7 +4,7 @@
 package Lingua::Interset::FeatureStructure;
 use strict;
 use warnings;
-our $VERSION = '2.045';
+our $VERSION = '2.046';
 
 use utf8;
 use open ':utf8';
@@ -1480,7 +1480,7 @@ sub get_other_for_tagset
     # We normally set the tagset feature even if there is no other feature.
     # However, it is not required that it is defined. (And sometimes we clear the tagset, e.g. during certain tests.)
     # Calling this method without defining $tagset makes much less sense but it is not fatal either.
-    if(defined($self->tagset()) && defined($tagset) && $self->tagset() eq $tagset)
+    if(defined($self->tagset()) && defined($tagset) && $self->tagset() eq $tagset && defined($self->other()))
     {
         return _duplicate_recursive($self->other());
     }
@@ -1735,6 +1735,7 @@ sub add_ufeatures
             my $ufeature = $1;
             my $uvalue = $2;
             my $feature = $map->{$ufeature};
+            next if(!defined($feature));
             my $value = lc($uvalue);
             # Interset uses for boolean features the value identical to feature name while universal features use "Yes".
             $value = $feature if($value eq 'yes');
@@ -2273,7 +2274,7 @@ Lingua::Interset::FeatureStructure - Definition of morphosyntactic features and
 
 =head1 VERSION
 
-version 2.045
+version 2.046
 
 =head1 SYNOPSIS
 
