@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::PL::Ipipan;
 use strict;
 use warnings;
-our $VERSION = '2.045';
+our $VERSION = '2.046';
 
 use utf8;
 use open ':utf8';
@@ -112,6 +112,10 @@ sub _create_atoms
             'conj'    => ['pos' => 'conj', 'conjtype' => 'coor'],
             # kublik = particle, interjection, indeclinable adjective etc. (wówczas, gdzie, się, też, wkrótce)
             'qub'     => ['pos' => 'part'],
+            # abbreviation (r, tys, zł, ul, proc)
+            # Most abbreviations in the Polish treebank are nouns but not all.
+            # For example, "ok" is the abbreviated preposition "około" ("about, approximately").
+            'brev'    => ['abbr' => 'abbr'],
             # ciało obce nominalne (no occurrences found)
             'xxs'     => ['foreign' => 'foreign', 'other' => {'pos' => 'xxs'}],
             # ciało obce luźne = foreign word (International, European, investment, Office, Deutsche)
@@ -157,7 +161,8 @@ sub _create_atoms
                        'sym'  => 'interp',
                        '@'    => { 'foreign' => { 'foreign' => { 'other/pos' => { 'xxs' => 'xxs',
                                                                                   '@'   => 'xxx' }},
-                                                  '@'       => 'ign' }}}
+                                                  '@'       => { 'abbr' => { 'abbr' => 'brev',
+                                                                             '@'    => 'ign' }}}}}
         }
     );
     # RODZAJ / GENDER ####################
@@ -332,6 +337,21 @@ sub _create_atoms
             'wok'  => 'long'
         }
     );
+    # IS THERE PUNCTUATION AFTER ABBREVIATION? ####################
+    $atoms{brev} = $self->create_atom
+    (
+        'surfeature' => 'brev',
+        'decode_map' =>
+        {
+            'npun' => ['other' => {'brev' => 'npun'}],
+            'pun'  => ['other' => {'brev' => 'pun'}]
+        },
+        'encode_map' =>
+        {
+            'other/brev' => { 'npun' => 'npun',
+                              '@'    => 'pun' }
+        }
+    );
     # MERGED ATOM TO DECODE ANY FEATURE VALUE ####################
     my @fatoms = map {$atoms{$_}} (@{$self->features_all()});
     $atoms{feature} = $self->create_merged_atom
@@ -351,7 +371,7 @@ sub _create_atoms
 sub _create_features_all
 {
     my $self = shift;
-    my @features = ('pos', 'gender', 'number', 'case', 'person', 'degree', 'aspect', 'negativeness', 'accentability', 'prepcase', 'accommodability', 'agglutination', 'vocalicity');
+    my @features = ('pos', 'gender', 'number', 'case', 'person', 'degree', 'aspect', 'negativeness', 'accentability', 'prepcase', 'accommodability', 'agglutination', 'vocalicity', 'brev');
     return \@features;
 }
 
@@ -413,7 +433,8 @@ sub _create_features_pos
         'prep'    => ['case', 'vocalicity'],
         'siebie'  => ['case'],
         'subst'   => ['number', 'case', 'gender'],
-        'winien'  => ['number', 'gender', 'aspect']
+        'winien'  => ['number', 'gender', 'aspect'],
+        'brev'    => ['brev']
     );
     return \%features;
 }
@@ -650,6 +671,8 @@ bedzie:pl:ter:imperf
 bedzie:sg:pri:imperf
 bedzie:sg:sec:imperf
 bedzie:sg:ter:imperf
+brev:npun
+brev:pun
 comp
 conj
 depr:pl:nom:m2
@@ -1759,7 +1782,7 @@ Lingua::Interset::Tagset::PL::Ipipan - Driver for the tagset of the Korpus Języ
 
 =head1 VERSION
 
-version 2.045
+version 2.046
 
 =head1 SYNOPSIS
 
